==> rust-opendal_0.44.1.orig.tar.gz: opendal-0.44.1/src/services/vercel_artifacts/writer.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

use async_trait::async_trait;
use http::StatusCode;

use super::backend::VercelArtifactsBackend;
use super::error::parse_error;
use crate::raw::*;
use crate::*;

pub struct VercelArtifactsWriter {
    backend: VercelArtifactsBackend,
    _op: OpWrite,

    path: String,
}

impl VercelArtifactsWriter {
    pub fn new(backend: VercelArtifactsBackend, op: OpWrite, path: String) -> Self {
        VercelArtifactsWriter {
            backend,
            _op: op,
            path,
        }
    }
}

#[async_trait]
impl oio::OneShotWrite for VercelArtifactsWriter {
    async fn write_once(&self, bs: &dyn oio::WriteBuf) -> Result<()> {
        let bs = oio::ChunkedBytes::from_vec(bs.vectored_bytes(bs.remaining()));

        let resp = self
            .backend
            .vercel_artifacts_put(
                self.path.as_str(),
                bs.len() as u64,
                AsyncBody::ChunkedBytes(bs),
            )
            .await?;

        let status = resp.status();

        match status {
            StatusCode::OK | StatusCode::ACCEPTED => {
                resp.into_body().consume().await?;
                Ok(())
            }
            _ => Err(parse_error(resp).await?),
        }
    }
}

==> rust-opendal_0.51.0.orig.tar.gz: opendal-0.51.0/src/services/vercel_artifacts/writer.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

use http::StatusCode;

use super::backend::VercelArtifactsBackend;
use super::error::parse_error;
use crate::raw::*;
use crate::*;

pub struct VercelArtifactsWriter {
    backend: VercelArtifactsBackend,
    _op: OpWrite,

    path: String,
}

impl VercelArtifactsWriter {
    pub fn new(backend: VercelArtifactsBackend, op: OpWrite, path: String) -> Self {
        VercelArtifactsWriter {
            backend,
            _op: op,
            path,
        }
    }
}

impl oio::OneShotWrite for VercelArtifactsWriter {
    async fn write_once(&self, bs: Buffer) -> Result<()> {
        let resp = self
            .backend
            .vercel_artifacts_put(self.path.as_str(), bs.len() as u64, bs)
            .await?;

        let status = resp.status();

        match status {
            StatusCode::OK | StatusCode::ACCEPTED => Ok(()),
            _ => Err(parse_error(resp)),
        }
    }
}
